Skip to contents

Plot PAVE vs TRACE adduct selection comparison

Usage

plot_compare_pave_adduct(
  pave.trace.merged,
  object,
  i.pol = 0,
  top.trace.adducts = 10L,
  return.data = FALSE
)

Arguments

pave.trace.merged

Data frame from a PAVE/TRACE feature merge.

object

MSdev object with xcms results.

i.pol

Polarity index. `0` for negative and `1` for positive.

top.trace.adducts

Maximum number of TRACE adduct labels to show.

return.data

Logical. If `TRUE`, return a list with `plot`, `p_adduct`, `p_intensity`, `data`, and `adduct_distribution`.

Value

A patchwork object with a stacked adduct barplot (PAVE and TRACE columns) and an intensity boxplot, or a list when `return.data = TRUE`.