Skip to contents

Plot PAVE fragment vs TRACE annotation comparison

Usage

plot_compare_pave_fragment(
  pave.trace.merged,
  object,
  i.pol = 0,
  top.trace.adducts = 8L,
  return.data = FALSE
)

Arguments

pave.trace.merged

Data frame from a PAVE/TRACE feature merge.

object

MSdev object with TRACE results in `object@advancedAna$TRACE_temp`.

i.pol

Polarity index. `0` for negative and `1` for positive.

top.trace.adducts

Maximum number of TRACE adduct labels to show in each polar barplot.

return.data

Logical. If `TRUE`, return a list with plots and data.

Value

A patchwork object with one polar barplot of TRACE adduct type from merged `trace_adduct_metabolite` features and one polar barplot of `fg.net` candidacy for `trace_metabolite`, or a list when `return.data` is `TRUE`.